

option nodate nonumber linesize=65 formdlim=" ";


data hearing;
    *infile "W:\Xuejun Li\SAS Book\dat\hearing_simple.txt";
	infile "C:\Users\Arthur\Documents\SAS Book\dat\hearing.txt";
    input id $ 1 - 4
	      race $ 6
          smoke $ 8 - 14
          Age 16 - 17
          Preg 19
          Hearing $ 21 - 23
          Income 25 - 30;
run;


/*
program 2.1
*/
title 'Evaluate the AGE variable';
proc means data=hearing n nmiss median maxdec=2;
	var age;
run;

/*
program 2.2
*/

data hearing2_1;
	set hearing;
	if age > 26 then age_hi = 1;
	else age_hi = 0;
run;

/*
program 2.3
*/
title 'Checking AGE_HI is created correctly';
proc means data=hearing2_1 n nmiss min max maxdec=2;
	class age_hi;
	var age;
run;


/*
program 2.4
*/

data hearing2_2;
    set hearing;
    if missing(age) eq 0 then 
        if age > 26 then age_hi = 1; else age_hi = 0;
run;


title 'Creating AGE_HI considering the missing value';
proc means data=hearing2_2 n nmiss min max maxdec=2;
    class age_hi;
    var age;
run;


/*
program 2.5
*/
title 'Use the MISSING option to show missing values';
proc means data=hearing2_2 n nmiss min max maxdec=2 missing;
    class age_hi;
    var age;
run;


/*
program 2.6
*/
title 'Check PREG variable';
proc freq data=hearing;
    tables preg/missing nocum nopercent;
run;

data hearing2_3;
    set hearing;
    if not missing(preg) then
        if preg then group = "A";
        else group = "B";
run;

title 'Check TRIAL is created correctly';
proc freq data=hearing2_3;
    tables preg*group/missing norow nocol nopercent;
run;

/*
program 2.7
*/
data hearing2_4;
    set hearing;
    if not missing(age) then
        if age > 26 then age_cat="old";
        else age_cat="young";
run;

title 'The first 5 observations of HEARING2_4 data set';
proc print data=hearing2_4(obs=5);
    var age age_cat;
run;


/*
program 2.8
*/
data hearing2_5;
    length age_cat $ 5;
    set hearing;
    if not missing(age) then
        if age > 26 then age_cat="old";
        else age_cat="young";	
run;

title 'The first 5 observations of HEARING2_5 data set';
proc print data=hearing2_5(obs=5);
    var age age_cat;
run;

/*
program 2.9
*/

title 'Frequency Tables: Preg by Smoke';
proc freq data=hearing;
    tables preg*smoke/missing norow nocol nopercent;
run;

data hearing2_6;
    set hearing;
    if not missing(preg) then
    do;
        preg_info = 1;
        if smoke ="current" and preg = 1 then preg_smoker = 1;
        else preg_smoker = 0;
    end;
    else preg_info = 0;
run;

title 'Check if PREG_SMOKER and PREG_INFO are created correctly';
proc freq data=hearing2_6;
    tables preg_smoker preg_info /missprint;
run;



/*
program 2.10
*/

data hearing2_7;
    set hearing;

	*method1;
    if age > 30 then agegroup1 = 3;
    else if age > 20 then agegroup1 =2;
    else if age > . then agegroup1=1;

    *method2;
    if not missing(age) then
        if age <=20 then agegroup2 = 1;
        else if age <= 30 then agegroup2 = 2;
        else agegroup2= 3;
run;

title 'Check AGEGROUP1 is created correctly';
proc means data=hearing2_7 missing n nmiss min max maxdec=2;
    class agegroup1;
    var age;
run;

title 'Check AGEGROUP2 is created correctly';
proc means data=hearing2_7 missing n nmiss min max maxdec=2;
    class agegroup2;
    var age;
run;



/*
program 2.11
*/
data hearing2_8;
    set hearing;
    length trial $4;

    if preg = 1 then do;
        trial = "A";
        requireInfo = 0;
    end;
    else if preg = 0 then do;
	    trial = "B";
        requireInfo = 0;
    end;
    else do;
	    trial = "Wait";
        requireInfo = 1;
	end;
run;

title 'Checking if TRIAL and REQUIREINFO are created correctly';
proc freq data=hearing2_8;
    tables (trial requireInfo)*preg/missing nocol norow nopercent;
run;



/*
program 2.12
*/

data hearing2_9;
    set hearing;
    length ethnic $ 10;
    select (race);
        when ("W", "H") ethnic = "white";
        when ("B", "A") ethnic = "non-white";
    end;
    select (preg);
        when (1) do;
            trial = "A";
            drug = "Treatment";
        end;
        when (0) do;
            trial = "B";
            drug = "placebo";
        end;
        otherwise;
    end;
    select(hearing);
        when ("yes") group = 1;
        when ("no") group = 2;
        otherwise group = 3;
    end;
    select;
        when (income > 100000) highincome = 1;
        when (income > .) highincome = 0;
        otherwise;
    end;
run;


title 'Check if ETHNIC, TRIAL, DRUG, and GROUP are created correctly';
proc freq data=hearing2_9;
    tables race*ethnic
           preg*trial
           preg*drug
           hearing*group/norow nocol nopercent missing;
run;

title 'Check if HIGHINCOME is created correctly';
proc means data=hearing2_9 missing n nmiss min max maxdec=2;
    class highincome;
    var income;
run;


/*
program 2.13
*/

data hearing2_10;
	set hearing;
	agegroup = (age>.) + (age>20) + (age>30);
run;

title 'Check if AGEGROUP is created correctly';
proc means data=hearing2_10 n nmiss min max maxdec=2 missing;
    class agegroup;
    var age;
run; 



